@@ -37,6 +37,8 @@
 #include "introspection.h"
 #include "object.h"
 
+#define MAX_CHILDREN 65536
+
 typedef struct _MatchRulePrivate MatchRulePrivate;
 struct _MatchRulePrivate
 {
@@ -197,7 +199,7 @@ match_roles_all_p (AtkObject *child, gint *roles)
   else if (roles[1] != BITARRAY_SEQ_TERM)
     return FALSE;
 
-  return (atk_object_get_role (child) == roles[0]);
+  return (spi_get_role (child) == roles[0]);
 }
 
 static gboolean
@@ -221,13 +223,13 @@ match_roles_any_p (AtkObject *child, gint *roles)
 static gboolean
 match_roles_none_p (AtkObject *child, gint *roles)
 {
-  AtkRole role;
+  AtspiRole role;
   int i;
 
   if (roles == NULL || roles[0] == BITARRAY_SEQ_TERM)
     return TRUE;
 
-  role = atk_object_get_role (child);
+  role = spi_get_role (child);
 
   for (i = 0; roles[i] != BITARRAY_SEQ_TERM; i++)
     if (role == roles[i])
@@ -485,6 +487,8 @@ sort_order_canonical (MatchRulePrivate *mrp, GList *ls, gint kount, gint max, At
   glong acount = atk_object_get_n_accessible_children (obj);
   gboolean prev = pobj ? TRUE : FALSE;
 
+  if (acount > MAX_CHILDREN)
+    acount = MAX_CHILDREN;
   for (; i < acount && (max == 0 || kount < max); i++)
     {
       AtkObject *child = atk_object_ref_accessible_child (obj, i);
@@ -552,9 +556,11 @@ sort_order_rev_canonical (MatchRulePrivate *mrp, GList *ls, gint kount, gint max
       while (nextobj && atk_object_get_n_accessible_children (nextobj) > 0)
         {
           AtkObject *follow;
+          gint count = atk_object_get_n_accessible_children (nextobj);
+          if (count > MAX_CHILDREN)
+            count = MAX_CHILDREN;
 
-          follow = atk_object_ref_accessible_child (nextobj,
-                                                    atk_object_get_n_accessible_children (nextobj) - 1);
+          follow = atk_object_ref_accessible_child (nextobj, count - 1);
           g_object_unref (nextobj);
           nextobj = follow;
         }
@@ -1124,6 +1130,8 @@ append_accessible_properties (DBusMessageIter *iter, AtkObject *obj, GArray *pro
         return;
     }
   count = atk_object_get_n_accessible_children (obj);
+  if (count > MAX_CHILDREN)
+    count = MAX_CHILDREN;
   for (i = 0; i < count; i++)
     {
       AtkObject *child = atk_object_ref_accessible_child (obj, i);
